@@ -2,6 +2,9 @@ package SReview::Config::Common;
 
 use SReview::Config;
 
+use strict;
+use warnings;
+
 sub get_default_cfile {
 	my $dir = $ENV{SREVIEW_WDIR};
 	my $write = shift;
@@ -34,7 +37,7 @@ sub setup {
 	$config->define('pubdir', 'The directory on the file system where files served by the webinterface should be stored', '/srv/sreview/web/public');
 	$config->define('workdir', 'A directory where encoder jobs can create a subdirectory for temporary files', '/tmp');
 	$config->define('outputdir', 'The base directory under which SReview should place the final released files', '/srv/sreview/output');
-	$config->define('output_subdirs', 'An array of fields to be used to create subdirectories under the output directory.', ['event', 'room', 'startdate']);
+	$config->define('output_subdirs', 'An array of fields to be used to create subdirectories under the output directory.', ['event', 'room', 'date']);
 	$config->define('script_output', 'The directory to which the output of scripts should be redirected', '/srv/sreview/script-output');
 	$config->define('preroll_template', 'An SVG template to be used as opening credits. Should have the same nominal dimensions (in pixels) as the video assets.', undef);
 	$config->define('postroll_template', 'An SVG template to be used as closing credits. Should have the same nominal dimensions (in pixels) as the video assets.', undef);
